import {Component, ElementRef, ViewChild} from '@angular/core';
import {trigger, state, style, animate, transition} from '@angular/animations';
import {TestChatCompletion, TestChatMessage} from '../class-chat-completion';

@Component({
  selector: 'app-mock-interviews',
  templateUrl: './mock-interviews.component.html',
  styleUrls: ['./mock-interviews.component.scss'],
  animations: [
    trigger('fadeAnimation', [
      state('visible', style({opacity: 1})),
      state('hidden', style({opacity: 0})),
      transition('visible => hidden', animate('500ms')),
    ])
  ]
})
export class MockInterviewsComponent {
  showContent: boolean = false;
  showProgress: boolean = false;
  progress: number = 0;

  startAnimation() {
    this.showProgress = true;
    this.showContent = true;
  }

  completion: TestChatCompletion
  @ViewChild('chatWindow', {static: false}) chatWindow!: ElementRef;


  constructor() {
    this.completion = new TestChatCompletion(this.messagesList)

  }

  messagesList: Array<TestChatMessage> = [
    {
      role: "assistant",
      content: "哈喽我的您的面试官,请点击发送,我们将准备开始面试"
    },
  ]

  inputText = '';

  getAvatar(role: string): string {
    if (role === 'assistant') {
      return 'assets/images/page-mine/myAvatar.png';
    } else {
      return 'assets/images/page-mine/myAvatar.png';
    }
  }

  getReceived(role: string): boolean {
    return role !== 'assistant';
  }

  handleShiftEnter() {
    this.inputText += '?';
  }

  handleEnter() {
    this.send()
  }

  handleKeyDown(event: KeyboardEvent) {
    if (event.shiftKey && event.key === 'Enter') {
      event.preventDefault()
      this.handleShiftEnter();
    } else if (event.key === 'Enter') {
      event.preventDefault()
      this.handleEnter();
    }
  }

  isStart: number = 0


  // 滚动到底部
  scrollToBottom() {
    const chatWindow = this.chatWindow.nativeElement;
    chatWindow.scrollTop = chatWindow.scrollHeight;
  }

  // 在视图检查后滚动到底部
  ngAfterViewChecked() {
    this.scrollToBottom();
  }

  send() {
    if (this.isStart == 0) {
      this.getQuestion()
      this.isStart += 1
    }
    if (this.isStart == 1) {
      this.messagesList.push({
        role: "user",
        content: "开始面试",
      });
      this.inputText = "";
      this.completion.createCompletionByStream();
      this.isStart += 1
      return;
    }
    if (this.inputText != '' && this.isStart > 1) {
      console.log(this.inputText);
      this.messagesList.push({
        role: "user",
        content: this.inputText += '回答完毕',
      });
      this.inputText = "";
      this.completion.createCompletionByStream();
      // 将滚动条滚动到底部
      this.scrollToBottom();
      return;
    }
  }

  getQuestion() {
    this.messagesList.push({
      role: "user",
      content: "您需要扮演一名公司的技术总监Jack，并主持一场，技术岗位招聘的第二轮技术面试。\n" +
        "您任职于大米科技，一家互联网智能手机公司，主要产品是性价比高的手机系列。\n" +
        "当前招聘前端开发工程师，需要熟悉HTML,JS,CSS基础，会Angular前端框架的优先，具有nodejs使用经验的优先。\n" +
        "您是比较负责且严谨的面试官，提问内容偏难。\n" +
        "接下来，请您根据面试岗位招聘要求，分别从技术能力、团队协作、职业规划等方面想出一个个面试问题。\n" +
        "每次只问一个问题,当用户回答:回答完毕时进行下一个问题,当完成了所有的三个问题之后请生成一份关于我面试的报告,其中包括我的每一个回答的得分,和回答的不足之处,以及可以改进的地方.您准备好了之后请回答我说:如果您现在准备好了,请回答开始面试我将开始这一次的面试"
    })
    this.completion.createCompletionByStream();
  }

}
